import { Component, OnInit } from '@angular/core';
import { FormGroup, FormControl, FormBuilder, Validators, AbstractControl } from '@angular/forms'
import { Router, ActivatedRoute, Params } from '@angular/router';
import { TranslateService } from 'ng2-translate';
// Base components/services --------------------------------------------------------------------
import { BaseComponent } from '../shared/base.component';
import { LanguageService } from '../shared/language.service';
// Core or Utils components/services -----------------------------------------------------------
import { Helper } from '../shared/helper';
import { LoggerService } from '../shared/logger.service';
// Models/APIs ---------------------------------------------------------------------------------
import * as Models from 'accounts-services-ui';
// Other components/services -------------------------------------------------------------------
import { AccountBalanceService }  from './account-balance.service';

@Component({
    selector: 'account-balance',
    templateUrl: './account-balance.component.html'
})
export class AccountBalanceComponent extends BaseComponent implements OnInit {
	protected accountBalance: Models.AccountBalance = {};

	constructor(private languageService : LanguageService,
			translate : TranslateService,
			private formBuilder: FormBuilder,
			private route: ActivatedRoute,
			private router: Router,
            private logger: LoggerService,
			private accountBalanceService : AccountBalanceService){
        super(languageService, translate);
    }

    ngOnInit() {
    	// get account balance data
		this.accountBalanceService.getAlertDetails(this.accountNumber)
			.subscribe(
                (_instance: Models.AccountBalanceAlertResponse) => {
                    if (this.logger.enabled) {
                        this.logger.log("Account balance response: ", _instance);
                    }
                    
                    // replace with ?. when available
                    let returnCode: number = _instance? (_instance.baseResponse? _instance.baseResponse.returnCode : null) : null;
                    if (Helper.isSuccess(returnCode)) {
                        this.accountBalance = _instance.accountBalance;
                    } else {
                    	// TODO: no error handling???
                        //throw new Error(returnCode.toString());
                    }
                },
                error => {
                	// TODO: no error handling???
                    //throw new Error(AccountsSettings.RC_GENERIC_ERROR);
                }
			);
    }
}
