import { Component, OnInit, Input } from '@angular/core';
import { FormGroup, FormControl, FormBuilder, Validators, AbstractControl } from '@angular/forms'
import { Router, ActivatedRoute, Params } from '@angular/router';
import { TranslateService } from 'ng2-translate';
// Base components/services --------------------------------------------------------------------
import { BaseComponent } from '../shared/base.component';
import { LanguageService } from '../shared/language.service';
// Utils components/services -------------------------------------------------------------------
import { Helper } from '../shared/helper';
// Models/APIs ---------------------------------------------------------------------------------
import * as Models from 'accounts-services-ui';
// Other components/services -------------------------------------------------------------------
import { AccountBalanceService }  from './account-balance.service';
import { ModulePagesService } from 'navigation-services-ui';

@Component({
  	selector: 'past-due-alert',
  	templateUrl: './past-due-alert.component.html'
})
export class PastDueAlertComponent extends BaseComponent {
	@Input() accountBalance: Models.AccountBalance = {}; 

	constructor(private route: ActivatedRoute,
			private modulePagesService: ModulePagesService,	
			private router: Router,
			private languageService : LanguageService,
			translate : TranslateService){
        super(languageService, translate);
    }

    /**
	 * Check if it is past due date then display red banner message
	 *
     * @return {boolean} [description]
     */
 	get pastDue(): boolean {
 		return !Helper.isEmpty(this.accountBalance) && this.accountBalance.isPastDue;
 	}

 	/**
 	 * 101 Message with a link to reconnect service
 	 *
 	 * @return {boolean} [description]
 	 */
 	get reconnectService(): boolean {
 		return !Helper.isEmpty(this.accountBalance.pastDueAlert)
 				&& this.accountBalance.pastDueAlert.customReturnCode === 101;
 		// TODO: offer link.reconnect_service
 	}

 	/**
 	 * 102 message with a link to make a payment arrangement
 	 *
 	 * @return {boolean} [description]
 	 */
 	get makePaymentArragement(): boolean {
 		return !Helper.isEmpty(this.accountBalance.pastDueAlert)
 				&& this.accountBalance.pastDueAlert.customReturnCode === 102;
 		// TODO: offer link.make_payment_arrangement
 	}

 	/**
 	 * 103 message that service is disconnected and provide a link to the restart service / move in
 	 *
 	 * @return {boolean} [description]
 	 */
 	get serviceDisconnectedA(): boolean {
 		return !Helper.isEmpty(this.accountBalance.pastDueAlert)
 				&& this.accountBalance.pastDueAlert.customReturnCode === 103;
 		// TODO: offer link.service_disconnected_A
 	}

 	/**
 	 * 104 message that service is disconnected and provide a link to the restart service / move in
 	 *
 	 * @return {boolean} [description]
 	 */
 	get serviceDisconnectedS(): boolean {
 		return !Helper.isEmpty(this.accountBalance.pastDueAlert)
 				&& this.accountBalance.pastDueAlert.customReturnCode === 104;
 		// TODO: offer link.service_disconnected_S
 	}

 	/**
 	 * 105 message that service order for disconnect is scheduled
 	 *
 	 * @return {boolean} [description]
 	 */
 	get serviceScheduled(): boolean {
 		return !Helper.isEmpty(this.accountBalance.pastDueAlert)
 				&& this.accountBalance.pastDueAlert.customReturnCode === 105;
 		// TODO: offer link.service_scheduled
 	}

 	/**
 	 * 106 message that indicates the account is not eligible for online payments
 	 *
 	 * @return {boolean} [description]
 	 */
 	get onlinePaymentIneligible(): boolean {
 		return !Helper.isEmpty(this.accountBalance.pastDueAlert)
 				&& this.accountBalance.pastDueAlert.customReturnCode === 106;
 	}

 	/**
 	 * 107 message that future dated payments are scheduled with a link to see what's scheduled
 	 *
 	 * @return {boolean} [description]
 	 */
 	get futureDatedPayments(): boolean {
 		return !Helper.isEmpty(this.accountBalance.pastDueAlert)
 				&& this.accountBalance.pastDueAlert.customReturnCode === 107;
 		// TODO: offer link.future_dated_payments
 	}

 	/**
 	 * 108 To show generalize message coming from service.
 	 *
 	 * @return {boolean} [description]
 	 */
 	get showMessageComingFromService(): boolean {
 		return !Helper.isEmpty(this.accountBalance.pastDueAlert)
 				&& this.accountBalance.pastDueAlert.customReturnCode === 108
 				&& !Helper.isStringEmpty(this.accountBalance.pastDueAlert.message);
 	}

 	/**
 	 * Show default message
 	 * .
 	 * @return {boolean} [description]
 	 */
 	get showDefaultMessage(): boolean {
 		return !Helper.isEmpty(this.accountBalance.pastDueAlert)
 				&& this.accountBalance.pastDueAlert.customReturnCode === 108
 				&& Helper.isStringEmpty(this.accountBalance.pastDueAlert.message);
 	}

	paybill() {
        let url = this.modulePagesService.getPageUrl(this.modulePagesService.pageTypeEnum.PAYMENT,true)+'#/';
        window.location.assign(url);
    }

}
