import { Component, EventEmitter, OnInit, Output } from '@angular/core';
import { FormGroup, FormControl, FormBuilder, Validators, AbstractControl } from '@angular/forms'
import { Router, ActivatedRoute, Params } from '@angular/router';
import { BasicAccountInfoService }  from './basic-account-info.service';
import { LanguageService } from '../shared/language.service';
import { TranslateService } from 'ng2-translate';
import { BaseComponent } from '../shared/base.component';
import * as Api from 'accounts-services-ui';
import {MessageService} from "../shared/message.service";

@Component({
  selector: 'basic-account-info',
  templateUrl: './basic-account-info.component.html'
})
export class BasicAccountInfoComponent extends BaseComponent{
    public isLoading: boolean = false;
    public isProcessing: boolean = false;
    private accountNickName : string;
    private displayPanel : boolean = false;
    private addNameForm : FormGroup;
    private giveAName : AbstractControl;
    private listOfAddress : string[] = [];
    private subListOfAddress : string[] = [];
    private nameOnAccount : string;
    private submitAttempt : boolean = false;
    private hasNickName : boolean = false;
    private addressCounter : number = 3;
	private isLockedAccount: boolean = true;

    constructor(public api: Api.BasicinfoApi, private basicAcctInfoService : BasicAccountInfoService,
                private formBuilder: FormBuilder, private route: ActivatedRoute, private router: Router,
                private messageService: MessageService, private languageService : LanguageService,
                translate : TranslateService){

            super(languageService, translate);

    }

    @Output() mobileHideEvent: EventEmitter<boolean> = new EventEmitter();
    public mobileHide:boolean = true;

    ngOnInit(): void {
            this.addNameForm = this.formBuilder.group({
                'giveAName': ['', [ Validators.required]]
            });
            this.giveAName = this.addNameForm.controls['giveAName'];
            this.initLoading();
    }

    initLoading() : void{
        this.isLoading = true;
        this.basicAcctInfoService.getAccountBasicInfo(this.accountNumber).subscribe(
            accountInformation => {
				// disable Self Service
				if (accountInformation) {
					this.basicAcctInfoService.setAccountInformation(accountInformation);
					if (accountInformation.isFraudAlert && !accountInformation.isAgent) {
						this.isLockedAccount = true;
					} else {
						this.isLockedAccount = false;
					}
				}
                this.isLoading = false;
                if(accountInformation['utilityAccountId']){
                    this.accountNickName = accountInformation.nickName;
                    this.nameOnAccount = accountInformation.nameOnAccount;
                    this.hasNickName = accountInformation.nickName?true:false;
                    if(typeof accountInformation.addresses != "undefined"){
                        var idx: number = 0;
                        accountInformation.addresses.forEach((address : Api.Address) => {
                           this.listOfAddress.push(address.addressDescription);
                            if(idx < 3){
                                 this.subListOfAddress.push(address.addressDescription);
                            }
                            idx++;
                        });
                       
                    }
                } else {
                    this.isLoading = false;
                    this.messageService.observer('account-profile.message.system_error');
                }
        }, error => {
            this.isLoading = false;
            this.messageService.observer('account-profile.message.system_error');
        });
    }

    toggleMobileHide() {
        this.mobileHide = !this.mobileHide;
        this.mobileHideEvent.emit(this.mobileHide);
    }

    hasMoreAddressLength() : number {
        return this.listOfAddress.length - this.subListOfAddress.length;
    }
    
    popData() : void {
        const currentIdx = this.subListOfAddress.length;
        var moreAddress: string[] = [];
        if( this.hasMoreAddressLength() >= 3){ //show 3 mores addresses
            moreAddress = this.listOfAddress.filter((value, index) => index >= currentIdx && index < currentIdx + 3);
        } else if(this.hasMoreAddressLength() > 0){ //otherwise, show the rest
            moreAddress = this.listOfAddress.filter((value, index) => index >= currentIdx);
        }

        // add more addresses to display list
        this.subListOfAddress = this.subListOfAddress.concat(moreAddress);
    }

    addNameSubmit(addNameForm : any , valid : boolean){
        if(valid){
			this.isProcessing = true;
			this.submitAttempt = true;

            var nickNameRequest : Api.NickNameUpdateRequest = {};
            nickNameRequest.baseRequest = {};
            nickNameRequest.baseRequest.utilityAccountId = this.accountNumber;
            nickNameRequest.nickName = this.giveAName.value;
            this.basicAcctInfoService.updateNickName(nickNameRequest).subscribe(
                (_instance : Api.NickNameUpdateResponse) => {
                    this.isProcessing = false;
                    if(_instance.baseResponse.returnCode == 0){
                        this.displayPanel = false;
                        this.accountNickName = this.giveAName.value;
                        this.hasNickName = true;
                    }
                });
        }
    }

	onClickDisplayAddNickName(): void {
		this.displayPanel = true;
	}

	onClickCloseAddNickName(): void {
		this.displayPanel = false;
	}
}
