import { Injectable } from '@angular/core';
import { Headers, Http } from '@angular/http';
import * as Api from 'accounts-services-ui';
import { Observable, Subject, BehaviorSubject } from 'rxjs';

@Injectable()
export class BasicAccountInfoService {
	private headers = new Headers({'Content-Type': 'application/json'});
    private _accountInformation: Subject<Api.AccountInformation> = new BehaviorSubject<Api.AccountInformation>(null);

	constructor(private http: Http, 
		private accountService: Api.AccountApi, 
		private basicInfoApi: Api.BasicinfoApi){}
      
	/**
	 * Share account information to all observer
	 */
	get accountInformationObservable(): Observable<Api.AccountInformation> {
        return this._accountInformation.asObservable();
    }

	/**
	 * Set account information for sharing to all observer
	 */
	setAccountInformation(accountInformation: Api.AccountInformation): void {
        this._accountInformation.next(accountInformation);
    }
	  
	/**
	 * Get a entity of basic account info
	 * @param
	 *      accountNumber - string
	 * @return a UserAccountProfile entity
	 */
	getAccountBasicInfo(utilityAccountId : string): Observable<Api.AccountInformation> {
		return this.accountService.getAccount(utilityAccountId);
	}

	/**
	 * Update a user profile
	 * @param
	 *      accountNumber - string
	 *      emailAddress - string
	 *      accountNickName - string
	 *      phoneNumber - string
	 * @return a new of UserAccountProfile entity
	 */
	updateNickName(updateNickNameRequest: Api.NickNameUpdateRequest): Observable<Api.NickNameUpdateResponse>{
		return this.basicInfoApi.updateNickName(updateNickNameRequest);
	}

}
