import { Component, OnInit, OnDestroy, OnChanges, Input, SimpleChanges } from '@angular/core';
import { CategorizedPage } from 'common-services-ui';
import { ModulePagesService } from "navigation-services-ui";
import { BasicAccountInfoService } from '../basic-account-info/basic-account-info.service';
import { NavService } from './nav.service'
import { NavData } from './nav.data';
import { ActivatedRoute, NavigationEnd, Router } from '@angular/router';

import * as Api from 'accounts-services-ui';

@Component({
	selector: 'app-left-hand-column',
	templateUrl: './left-hand-column.component.html',
	styleUrls: ['./left-hand-column.component.css']
})
export class LeftHandColumnComponent implements OnInit, OnDestroy {

	@Input()
	public selectedPath: string = "";

	public mobileHide: boolean = true;

	private isLockedAccount: boolean = false;
	private alive: boolean = true;

	private navData = new NavData();
	private leftNavData = this.navData.getLeftNav();
	private _pagesSubscription;
	private pages;

	pageTypes: typeof CategorizedPage.ModuleTypeEnum = CategorizedPage.ModuleTypeEnum;

	constructor(private modulePages: ModulePagesService,
		private basicAcctInfoService: BasicAccountInfoService,
		private navService: NavService,
		router: Router,
		route: ActivatedRoute) {
		// process nav data when route is changed. 
		// Terribly inefficient, needs to be refactored to only change active item
		router.events
			.filter(e => e instanceof NavigationEnd)
			.forEach(e => {
				this.processNavData();
			});
	}

	isSelectedPath(path): boolean {
		return path === this.selectedPath;
	}

	ngOnInit() {
		this.processNavData();
		this.basicAcctInfoService.accountInformationObservable
			.takeWhile(() => this.alive)
			.subscribe((accountInformation: Api.AccountInformation) => {
				if (accountInformation) {
					if (accountInformation.isFraudAlert && !accountInformation.isAgent) {
						this.isLockedAccount = true;
					} else {
						this.isLockedAccount = false;
					}
				}
				else {
					this.isLockedAccount = false;
				}
			},
			error => {
				// TODO: error handling
			});
	}

	toggleMenuCollapse(navItem) {
		navItem.open = !navItem.open;
	}

	processNavData() {
		if (this.modulePages.pagesUpdate.observers.length) {
			this.navService.processNavData(this.modulePages, this.pageTypes, this.leftNavData, this.pages);
		} else if (this.modulePages.pages) {
			this.pages = this.modulePages.pages;
			this.navService.processNavData(this.modulePages, this.pageTypes, this.leftNavData, this.pages);
		} else {
			this.modulePages.pagesUpdate
				.takeWhile(() => this.alive)
				.subscribe((pages: Array<CategorizedPage>) => {
					this.pages = pages;
					this.navService.processNavData(this.modulePages, this.pageTypes, this.leftNavData, pages);
				}
				);
		}

	}

	mobileHideChange(mobileHideEvent: boolean) {
		this.mobileHide = mobileHideEvent;
	}

	ngOnDestroy() {
		// to avoid memory leak
		this.alive = false;
		// this.modulePages.pagesUpdate.unsubscribe();
	}
}
