import { Injectable } from '@angular/core';
import { CategorizedPage } from 'common-services-ui';
import { ModulePagesService } from 'navigation-services-ui';

@Injectable()
export class NavService{
	
	/**
	 * Gets the value that will be placed into the href attr
	 * 
	 * @param	string 	pageName 
	 * @param 	string	pageRoute 
	 * @param 	boolean	privatePage 
	 * @return 	string
	 */
	getPageHref(modulePages:ModulePagesService, pageTypes:typeof CategorizedPage.ModuleTypeEnum, pageName:string, pageRoute:string, privatePage:boolean, pages: Array<CategorizedPage>):string {
		let pagePath = modulePages.getPageUrl(pageTypes[pageName], privatePage, pages);
		return pagePath+pageRoute;
	}

	/**
	 * Is the current link selected?
	 * 
	 * @param	string 	pageName 
	 * @param 	string	pageRoute 
	 * @param 	boolean	privatePage 
	 * @return  boolean
	 */
	isSelected(modulePages:ModulePagesService, pageTypes:typeof CategorizedPage.ModuleTypeEnum, pageName:string, pageRoute:string, privatePage: boolean, pages: Array<CategorizedPage>):boolean {
		let pagePath = modulePages.getPageUrl(pageTypes[pageName], privatePage, pages);
		let selectedPage = pagePath.toLowerCase() === (<any>window).Liferay.ThemeDisplay.getLayoutRelativeURL().toLowerCase();
		let selectedPath = pageRoute.toLowerCase() === window.location.hash.toLowerCase();
		return (selectedPage && selectedPath);
	}

	/**
	 * Add extra properties to nav data object
	 * 
	 * @param 	object	navData 
	 */
	processNavData(modulePages:ModulePagesService, pageTypes:typeof CategorizedPage.ModuleTypeEnum, navData, pages: Array<CategorizedPage>): boolean {
		var active: boolean = false;
		for(let navItem of navData) {
			navItem.pageHref = this.getPageHref(modulePages, pageTypes, navItem.pageName, navItem.pageRoute, navItem.privatePage, pages);
			if (navItem.children) {
				// Recursively processes descendants
				navItem.open = this.processNavData(modulePages, pageTypes, navItem.children, pages);
			} else {
				navItem.pageSelected = this.isSelected(modulePages, pageTypes, navItem.pageName, navItem.pageRoute, navItem.privatePage, pages);
				navItem.open = navItem.pageSelected;
			}
			active = navItem.open || active;
		}
		return active;
	}
}
