import { TranslateService } from 'ng2-translate';
import { LanguageService } from './language.service';
import { MessageService } from './message.service';
import * as Models from 'accounts-services-ui';

export class BaseComponent {
    // public isDebug : boolean = true;
    private currentLanguage : string;
    public accountNumber : string;
    public businessPartnerId : string;
    public companyType : string;

    constructor(public langService : LanguageService, public translate: TranslateService, msgService?: MessageService) {
        var browserLang = sessionStorage.getItem('com.spireenergy.language');
        //if not find by default get from browser
        if (browserLang == null) {
            browserLang = translate.getBrowserLang();
            translate.setDefaultLang(browserLang);
        }
        this.use(browserLang);
        // subscribe for all components when had something changed
        langService.getLanguageChangeEmitter().subscribe((item: string) => this.use(item));

        // Get value from session
        this.getSessionData();

        // invisible message
        if(msgService) {
            msgService.observer("");
        }
    }


    private getSessionData() : void {
        var utilityAccountObj = JSON.parse(sessionStorage.getItem('com.spireenergy.selectedUtilityAccount'));
        // if(this.isDebug){
        //     console.log(utilityAccountObj);
        // }
        if(utilityAccountObj) {
            this.accountNumber =  utilityAccountObj.utilityAccountId;
            this.businessPartnerId = utilityAccountObj.businessPartnerId;
            this.companyType = utilityAccountObj.companyType;
        } else {
            this.accountNumber = '';
            this.businessPartnerId = '';
            this.companyType = '';
            this.setSessionData();
        }
        // if(this.isDebug){
        //     console.log("Account Number from session store: "+ this.accountNumber);
        // }
    }

    public setSessionData(): void {
        sessionStorage.setItem('com.spireenergy.selectedUtilityAccount', JSON.stringify({
            utilityAccountId: this.accountNumber,
            businessPartnerId: this.businessPartnerId,
            companyType : this.companyType
        }));
    }
    
    private use(lang : string) : void {
        // if(this.isDebug){
        //    console.log("changeLanguage: "+ lang);
        // }
        this.currentLanguage = lang;
        this.translate.use(lang.match(/en|fr/) ? lang : 'en');
    }

    public changeDefaultLang(lang : string) : void{
        this.translate.setDefaultLang(lang);
        sessionStorage.setItem('com.spireenergy.language' , lang);
    }

    /**
     * Get BaseRequest
     * @return {BaseRequest} [description]
     */
    protected getBaseRequest(): Models.BaseRequest {
        let baseRequest: Models.BaseRequest = {};
        baseRequest.utilityAccountId = this.accountNumber;

        return baseRequest;
    }
}
