/*
 * ---------------------------------------------------------------------------------------------------------
 * Name : ErrorMessageRender class
 * Title : ErrorMessageRender
 * Author : 91070
 * Creation Date : Jan 18, 2017
 * Purpose : Message handling when an exception is throwed
 * Functional Spec: SCC-89 Pay Bill w/ Credit Card (One-Time)
 * ----------------------------------------------------------------------------------------------------------
 */
import { Component, OnInit, Input } from '@angular/core';
import { TranslateService } from 'ng2-translate';
import { MessageService } from './message.service';
import { BaseComponent } from './base.component';
import { LanguageService } from './language.service';
import { LoggerService } from './logger.service';
import { Helper } from "./helper";
import { Settings } from "./settings";

@Component({
    selector: 'error-message',
    template : `
        <div class="field" *ngIf="messages != undefined && messages.length > 0">
         <div *ngFor="let message of messages"class="alert-danger">&#8226; {{message}}</div>
     </div>`
})
export class ErrorMessageRender extends BaseComponent implements OnInit{
    messages : string[] = [];

    /**
     * Constructor method to handle message data
     * @param
     *      langService - LanguageService entity
     *      translate - TranslateService entity
     *      msgService - MessageService entity
     * @return void
     */
    constructor(private messageService: MessageService, public langService :
            LanguageService, public translateService : TranslateService, private logger: LoggerService) {
        super(langService, translateService, messageService);
    }

    /**
     * Created a subscriber to observe data when it fired
     * @return void
     */
    ngOnInit() {
        this.messageService.messageObservable.subscribe(message => {
            this.messages = []; // At this time, only one message 1 time
            if(!Helper.isEmpty(message)) {
                this.translateService.get(message).subscribe(nonTranslatedMsg => {
                    this.messages.push(nonTranslatedMsg);
                    this.logger.log('App alert received: ', this.messages);
                    this.logger.log('App.alerts:', this.messages);
                });
            }
        });
    }
}