/* ---------------------------------------------------------------------------------------------------------
 * Name : LoggerService classs
 * Author : 91075
 * Purpose : Using for logging information
 * ----------------------------------------------------------------------------------------------------------
 */
import { Injectable } from '@angular/core';

@Injectable()
export class LoggerService {
    private isLoggerEnabled: boolean = false; // by default: false
    private loggerLevel: LoggerLevel = LoggerLevel.OFF; // by default: OFF

    public constructor() { }

    public setLoggerLevel(level: LoggerLevel): void {
        this.loggerLevel = level;
        this.isLoggerEnabled = !(this.loggerLevel === LoggerLevel.OFF);
    }

    get enabled(): boolean {
        return this.isLoggerEnabled;
    }

    public log(message: any, ...optionalParams: any[]): void {
        switch (this.loggerLevel) {
            case LoggerLevel.OFF:
                // do nothing
                break;
            case LoggerLevel.DEBUG:
                console.debug(message, optionalParams);
                break;
            case LoggerLevel.TRACE:
                console.trace(message, optionalParams);
                break;
            case LoggerLevel.INFO:
                console.info(message, optionalParams);
                break;
            case LoggerLevel.WARN:
                console.warn(message, optionalParams);
                break;
            case LoggerLevel.ERROR:
                console.error(message, optionalParams);
                break;
            default:
                // do nothing
                break;
        }
    }

    public info(message: any, ...optionalParams: any[]): void {
        if (this.loggerLevel === LoggerLevel.INFO) {
            console.info(message, optionalParams);
        }
    }

    public warn(message: any, ...optionalParams: any[]): void {
        if (this.loggerLevel === LoggerLevel.WARN) {
            console.warn(message, optionalParams);
        }
    }

    public error(message: any, ...optionalParams: any[]): void {
        if (this.loggerLevel === LoggerLevel.ERROR) {
            console.error(message, optionalParams);
        }
    }

    public debug(message: any, ...optionalParams: any[]): void {
        if (this.loggerLevel === LoggerLevel.DEBUG) {
            console.debug(message, optionalParams);
        }
    }

    public trace(message: any, ...optionalParams: any[]): void {
        if (this.loggerLevel === LoggerLevel.DEBUG) {
            console.trace(message, optionalParams);
        }
    }
}

export enum LoggerLevel {
    DEBUG = <any>'DEBUG',
    INFO = <any>'INFO',
    WARN = <any>'WARN',
    ERROR = <any>'ERROR',
    TRACE = <any>'TRACE',
    OFF = <any>'OFF'
}