import { NgModule }       from '@angular/core';
import { CommonModule }   from '@angular/common';
import { HttpModule, Http }    from '@angular/http';
import { FormsModule, ReactiveFormsModule }    from '@angular/forms';
import { TranslateModule, TranslateLoader, TranslateStaticLoader } from "ng2-translate";
import { AlertModule, ModalModule, CollapseModule } from "ng2-bootstrap";
import { AlertMessageComponent } from './alert-message.component';
import { ModalConfirmationComponent } from './modal-confirmation.component'
import { MessageService } from './message.service';
import { LanguageService } from './language.service';
import { LoggerService } from './logger.service';

@NgModule({
  imports: [
    //basic modules, must have
    CommonModule, HttpModule, 
    FormsModule, ReactiveFormsModule, 
    //other third-party modules
    TranslateModule, AlertModule, ModalModule, CollapseModule
  ],
  declarations: [
    AlertMessageComponent, ModalConfirmationComponent
  ],
  providers: [
    MessageService,
    LanguageService,
    LoggerService
  ],
  exports: [
    // basic modules
    CommonModule, HttpModule, 
    FormsModule, ReactiveFormsModule,
    //other third-party modules
    TranslateModule, AlertModule, ModalModule, CollapseModule,
    // components
    AlertMessageComponent, ModalConfirmationComponent
  ]
})
export class SharedModule {}

// Note:
// While reviewing our application, we noticed that many components requiring SharedModule 
// directives also use NgIf and NgFor from CommonModule and bind to component properties 
// with [(ngModel)], a directive in the FormsModule. Modules that declare these components 
// would have to import CommonModule, FormsModule and SharedModule.
//
// We can reduce the repetition by having SharedModule re-export CommonModule and FormsModule 
// so that importers of SharedModule get CommonModule and FormsModule for free.
//
// As it happens, the components declared by SharedModule itself don't bind with [(ngModel)]. 
// Technically, there is no need for SharedModule to import FormsModule.
//
// SharedModule can still export FormsModule without listing it among its imports.